import { CanActivate, ExecutionContext, Injectable } from '@nestjs/common';
import { Request } from 'express';
import { PrismaService } from '../prisma/prisma.service';

@Injectable()
export class WebAuthGuard implements CanActivate {
    constructor(private prismaService: PrismaService) {}

    async canActivate(context: ExecutionContext): Promise<boolean> {
        const req: Request = context.switchToHttp().getRequest();

        const token = req.headers.authorization;

        if (!token) return false;

        const group = await this.prismaService.group.findFirst({
            where: { code: token },
        });

        if (!group) return false;

        req.group = group;

        return true;
    }
}
